@@ -12,7 +12,10 @@
 #' Duplicated rows, as when "waveform" and "spectrogram" information are included for the same selection, will be removed.
 #' All selection files must contain "Selection", "Begin.Time" and "End.Time" columns.
 #' @param all.data Logical. If \code{TRUE} all columns in the selection files are returned, 
-#' keeping the name columns as in the 'Raven' files. Default is \code{FALSE}. Columns absent in some selection files will be filled with NA's.
+#' keeping the name columns as in the 'Raven' files. Default is \code{FALSE}. Columns absent in some selection files will 
+#' be filled with NA's. Note that when Raven selection files contain data from multiple sound files the  "Begin.Time" and 
+#' "End.Time" columns are relative to the position of the sound files in sequence of files riginally displayed by Raven.
+#' This data is corrected to the absolute time for each sound file only if \code{all.data = FALSE}.
 #' @param recursive Logical. If \code{TRUE} the listing recurse into sub-directories.
 #' @param name.from.file Logical. If \code{TRUE} the sound file names are extracted from the selection text file name. 
 #' It asssumes that selections files contained the suffix "Table.1.selections.txt" or "selections.txt". 
@@ -36,7 +39,7 @@
 #'  If sound.file.col is provided the data frame  will also contain a 'sound.files' column. In addition, all rows with duplicated 
 #'  data are removed. This is useful when both spectrogram and waveform views are included in the 'Raven' selection files. If all.data is set to \code{TRUE} then all columns in the 'Raven' selection files are returned. 
 #'  If individual selection files contain information about multiple sound files the function will correct the time
-#'  parameters (start and end) only if 1) the 'File Offset (s)' is also included in the selection file and 2) the sound file column has been provided (using 'sound.file.col' or 'name.from.file' arguments).
+#'  parameters (start and end) only if 1) the 'File Offset (s)' is also included in the selection file and 2) the sound file column has been provided (using 'sound.file.col' or 'name.from.file' arguments) and 3) 'all.data' is \code{FALSE}.
 #' @details The function import 'Raven' selection data from many files simultaneously. Files must be in '.txt' format. Selection 
 #' files including data from mulitple recordings can also be imported. 
 #' @seealso \code{\link{imp_syrinx}} 
@@ -96,7 +99,7 @@ imp_raven <- function(path = NULL, sound.file.col = NULL, all.data = FALSE,
   read_sels_FUN <- function(i, sel.txt, sel.txt2, all.data, freq.cols, sound.file.col, name.from.file)
   {  
     # read selection file
-    a <- try(utils::read.table(sel.txt[i], header = TRUE, sep = "\t", fill = TRUE, stringsAsFactors = FALSE, check.names = FALSE), silent = TRUE)
+    a <- try(utils::read.delim(sel.txt[i], header = TRUE, sep = "\t", fill = TRUE, stringsAsFactors = FALSE, check.names = FALSE), silent = TRUE)
     
     if (class(a) != "try-error")
     {   
@@ -113,45 +116,45 @@ imp_raven <- function(path = NULL, sound.file.col = NULL, all.data = FALSE,
           sound.files <- a[, grep(sound.file.col, colnames(a), ignore.case = TRUE)]
 
         # put data in data frame      
-        c <- try(data.frame(channel = a[, grep("channel", colnames(a), ignore.case = TRUE)],
+        d <- try(data.frame(channel = a[, grep("channel", colnames(a), ignore.case = TRUE)],
                             selec = a[,grep("Selection$",colnames(a), ignore.case = TRUE)],
                             start = a[,grep("Begin.Time",colnames(a), ignore.case = TRUE)],
                             end = a[, grep("End.Time",colnames(a), ignore.case = TRUE)], selec.file = sel.txt2[i], stringsAsFactors = FALSE, check.names = FALSE), silent = TRUE)
         
         # add sound file column and offset info
         if (exists("sound.files")) {
-          c <- data.frame(sound.files, c) 
+          d <- data.frame(sound.files, d) 
     
           # fix start end if multiple files are found
          if (length(unique(sound.files)) > 1)
           { 
            if (!any(grepl("offset", names(a), ignore.case = TRUE))) stop(paste0("selections files from multiple sound files must contain an 'Offset' column (check ", sel.txt[i],")"))
           
-          c$file.offset.DELETE <- a[, grep("Offset", colnames(a), ignore.case = TRUE)]
-          c$end <- c$end - c$start
-          c$start <- c$file.offset.DELETE
-          c$end <- c$end + c$start
+          d$file.offset.DELETE <- as.numeric(a[, grep("Offset", colnames(a), ignore.case = TRUE)])
+          d$end <- as.numeric(d$end) - as.numeric(d$start)
+          d$start <- d$file.offset.DELETE
+          d$end <- d$end + d$start
           }
           }
         
         # add frequency columns 
         if (freq.cols)
         {
-        try(c$bottom.freq <- a[, grep("Low.Freq", colnames(a), ignore.case = TRUE)]/ 1000, silent = TRUE)
-        try(c$top.freq <- a[, grep("High.Freq", colnames(a), ignore.case = TRUE)]/ 1000, silent = TRUE)
+        try(d$bottom.freq <- a[, grep("Low.Freq", colnames(a), ignore.case = TRUE)]/ 1000, silent = TRUE)
+        try(d$top.freq <- a[, grep("High.Freq", colnames(a), ignore.case = TRUE)]/ 1000, silent = TRUE)
           }
         
-        if (all(c("High.Freq", "Low.Freq") %in% names(c)))
-          c <- c[c(1:(ncol(c) - 3), ncol(c):(ncol(c)-1), ncol(c) -2 )]
+        if (all(c("High.Freq", "Low.Freq") %in% names(d)))
+          d <- d[c(1:(ncol(d) - 3), ncol(d):(ncol(d)-1), ncol(d) -2 )]
       
         } else { # if all data needed
           # read data
-          c <- try(data.frame(a, selec.file = sel.txt2[i], stringsAsFactors = FALSE, check.names = FALSE), silent = TRUE) 
+          d <- try(data.frame(a, selec.file = sel.txt2[i], stringsAsFactors = FALSE, check.names = FALSE), silent = TRUE) 
   
-          if (class(c) == "try-error") c <- NA
+          if (class(d) == "try-error") d <- NA
       }
-      } else c <- NA
-      return(c)
+      } else d <- NA
+      return(d)
  }
 
   # set pb options 
