@@ -50,7 +50,7 @@ imp_syrinx <- function(path = NULL, all.data = FALSE, recursive = FALSE,
   on.exit(setwd(wd))
   
   #check path to working directory
-  if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
+  if (is.null(path)) path <- getwd() else {if (!dir.exists(path)) stop("'path' provided does not exist") else
     setwd(path)
   }  
 
@@ -60,10 +60,10 @@ sel.txt2 <- list.files(full.names = FALSE)
 sel.txt <- sel.txt[grep(".log$|.txt$",ignore.case = TRUE, sel.txt)]
 sel.txt2 <- sel.txt2[grep(".log$|.txt$",ignore.case = TRUE, sel.txt2)]
 
-if(length(sel.txt) == 0) stop("No selection files in working directory/'path' provided")
+if (length(sel.txt) == 0) stop("No selection files in working directory/'path' provided")
 
 b<-NULL
-if(substring(text = readLines(sel.txt[1])[1], first = 0, last = 9) == "fieldkey:") field <- T else field <- F
+if (substring(text = readLines(sel.txt[1])[1], first = 0, last = 9) == "fieldkey:") field <- T else field <- F
 
 # set pb options 
 pbapply::pboptions(type = ifelse(pb, "timer", "none"))
@@ -74,34 +74,34 @@ if (Sys.info()[1] == "Windows" & parallel > 1)
 
 clist <- pbapply::pblapply(1:length(sel.txt), cl = cl, function(i)
   {    
-  if(field)  {
+  if (field)  {
     
     a <- try(utils::read.table(sel.txt[i], header = TRUE, sep = "\t", fill = TRUE, stringsAsFactors = FALSE), silent = TRUE) 
-    if(!exclude & class(a) == "try-error") stop(paste("The selection file",sel.txt[i], "cannot be read"))
+    if (!exclude & class(a) == "try-error") stop(paste("The selection file",sel.txt[i], "cannot be read"))
     
-  if(!class(a) == "try-error" & !all.data) { c <- data.frame(selec.file = sel.txt2[i], sound.files = a[, grep("soundfile",colnames(a))],
+  if (!class(a) == "try-error" & !all.data) { c <- data.frame(selec.file = sel.txt2[i], sound.files = a[, grep("soundfile",colnames(a))],
                                 selec = 1,
                                 start = a[, grep("lefttimesec",colnames(a))],
                                 end = a[, grep("righttimesec",colnames(a))],
                                 bottom.freq = a[, grep("bottomfreq",colnames(a))],
                                 top.freq = a[, grep("topfreq",colnames(a))])
-  for(i in 2:nrow(c)) if(c$selec.file[i] == c$selec.file[i-1]) c$selec[i]<-c$selec[i-1] + 1
+  for(i in 2:nrow(c)) if (c$selec.file[i] == c$selec.file[i-1]) c$selec[i]<-c$selec[i-1] + 1
   } else c<-a 
                                 } else {
             a <- try(utils::read.table(sel.txt[i], header = FALSE, sep = "\t", fill = TRUE, stringsAsFactors = FALSE), silent = TRUE) 
-            if(!exclude & class(a) == "try-error") stop(paste("The selection file",sel.txt[i], "cannot be read"))
+            if (!exclude & class(a) == "try-error") stop(paste("The selection file",sel.txt[i], "cannot be read"))
             
-            if(!class(a) == "try-error") 
+            if (!class(a) == "try-error") 
               { 
               c <- a[, seq(2, ncol(a), by =2)]
            colnames(c) <- gsub(":", "", unlist(a[1, seq(1,ncol(a), by =2)]), fixed = TRUE)
-           if(!all.data) {c<-data.frame(sound.files = c[, grep("selected",colnames(c), ignore.case = TRUE)],
+           if (!all.data) {c<-data.frame(sound.files = c[, grep("selected",colnames(c), ignore.case = TRUE)],
                                        selec = 1,
                                        start = c[, grep("lefttime",colnames(c), ignore.case = TRUE)],
                                        end = c[, grep("righttime",colnames(c), ignore.case = TRUE)],
                                        bottom.freq = c[, grep("bottomfreq",colnames(c), ignore.case = TRUE)],
                                        top.freq = c[, grep("topfreq",colnames(c), ignore.case = TRUE)])
-           for(i in 2:nrow(c)) if(c$sound.files[i] == c$sound.files[i-1]) c$selec[i] <- c$selec[i-1] + 1} 
+           for(i in 2:nrow(c)) if (c$sound.files[i] == c$sound.files[i-1]) c$selec[i] <- c$selec[i-1] + 1} 
            } else c <- a         
                                 }
   return(c)
@@ -109,12 +109,12 @@ clist <- pbapply::pblapply(1:length(sel.txt), cl = cl, function(i)
 
 clist <- clist[sapply(clist, is.data.frame)]
 b <- do.call("rbind", clist)
-if(!all.data) if(any(is.na(b$start))) warning("NAs found (empty rows)")
+if (!all.data) if (any(is.na(b$start))) warning("NAs found (empty rows)")
 
 b <- b[!duplicated(b), ]
 
 options(warn = -1)
-if(!all.data)
+if (!all.data)
 {
   b$start <- as.numeric(b$start)
   b$end <- as.numeric(b$end)
@@ -124,7 +124,7 @@ if(!all.data)
   } else b <-b[b[,2] != names(b)[2],]
 
 # convert to hz
-if(hz.to.khz & !all.data & all(c("bottom.freq", "top.freq") %in% names(b)))
+if (hz.to.khz & !all.data & all(c("bottom.freq", "top.freq") %in% names(b)))
   {b$bottom.freq <- as.numeric(b$bottom.freq) / 1000 
   b$top.freq <- as.numeric(b$top.freq) / 1000 
 }
